# File: Pyro-2.1.spec
#
# PYthon Remote Objects (Pyro)
#
# An independent 'BuildRoot:' directive is used so that that this package
# can be built in the /var/tmp directory, for the case where the existing
# software on the build host would be disrupted by installing-after-build-
# to-package onto that system.
#
# Sample Package Names:
#   Pyro-2.1-1.noarch.rpm
#
####

####
# Section: Preamble (Items Displayed When Users Request Info About Package)
#
# The order of the entries below is unimportant.
#
####

%define PYTHONAPP /usr/bin/python2.1
%define PYTHONDIR python2.1

Name:               Pyro
Version:            2.1
Release:            1
Copyright:          LGPL
Vendor:             Irmen de Jon
URL:                http://pyro.sourceforge.net/
Packager:           Jeff Rush <jrush@taupro.com>
BuildRoot:          /var/tmp/Pyro-%{version}-rootdir
Prereq:             python2 python2-devel /sbin/chkconfig

Source0: Pyro-2_1.tar.gz
Source1: Pyro-%{version}.ns.init
Source2: Pyro-%{version}.es.init

#----------------------------------------------------------------------
Summary:            PYthon Remote Objects, a distributed object calling system.
Group:              Development/Web Applications
Requires:           python2 >= 2.0
BuildArchitectures: noarch

%description

Pyro is an acronym for PYthon Remote Objects. It is a basic
Distributed Object Technology system written entirely in Python, and for
use in Python only. With this, it closely resembles Java's Remote Method
Invocation (RMI).  It has less similarity to CORBA - which is a system
and language independent Distributed Object Technology and has much more
to offer than Pyro or RMI.  But Pyro is small, simple, fun and free!

########## 
#
# The following environment variables are automatically defined for use
# in any of the following shell scripts:
#
#   RPM_SOURCE_DIR      { where sources originally reside }
#   RPM_BUILD_DIR       { where sources get unpacked into }
#   RPM_DOC_DIR
#   RPM_OPT_FLAGS
#   RPM_ARCH
#   RPM_OS
#   RPM_ROOT_DIR
#   RPM_BUILD_ROOT      { where final images get placed before packaging }
#   RPM_PACKAGE_NAME
#   RPM_PACKAGE_VERSION
#   RPM_PACKAGE_RELEASE
#
##########

####
# Section: Prep Script (Prepare to Build; Usually Just Unpacking the Sources)
####
%prep
# Create Build Subdirectory and Unpack the Main Tar Ball
%setup -q -n %{name}-2_1

rm bin/*.bat

####
# Section: Build Script (Actually Perform the Build; Usually Just 'make')
####
#%build

####
# Section: Install-After-Build Script (Often Just 'make install')
####
%install
  rm -rf $RPM_BUILD_ROOT

  # Make the Necessary Directories
  install -m0755 --directory      $RPM_BUILD_ROOT/usr/lib/%{PYTHONDIR}/site-packages
  install -m0755 --directory      $RPM_BUILD_ROOT/usr/bin
  install -m0775 --directory      $RPM_BUILD_ROOT/var/log
  install -m0755 --directory      $RPM_BUILD_ROOT/etc/rc.d/init.d
  install -m755 --directory       $RPM_BUILD_ROOT/etc/profile.d
  install -m775 --directory       $RPM_BUILD_ROOT/var/pyro

  cp -Rdp Pyro/ $RPM_BUILD_ROOT/usr/lib/%{PYTHONDIR}/site-packages/

  cp bin/* $RPM_BUILD_ROOT/usr/bin/
  pushd $RPM_BUILD_ROOT/usr/bin
  %{PYTHONAPP} - <<EOF
import fileinput, string, glob
for l in fileinput.input(glob.glob('*'), inplace=1):  print string.replace(l, 'env python', 'env python2'),
EOF
  popd

  # Precompile Python Source for Faster Imports During Usage
  # (Since user of package may not have write-access to install directory)
  %{PYTHONAPP} -O /usr/lib/%{PYTHONDIR}/compileall.py    -d /usr/lib/%{PYTHONDIR}/  $RPM_BUILD_ROOT/usr/lib/%{PYTHONDIR}
  %{PYTHONAPP}    /usr/lib/%{PYTHONDIR}/compileall.py    -d /usr/lib/%{PYTHONDIR}/  $RPM_BUILD_ROOT/usr/lib/%{PYTHONDIR}

  #####
  # Create Shell Profiles to Set Environment Variables
  #####
  cat <<-EOF  >$RPM_BUILD_ROOT/etc/profile.d/pyro.sh
	if [ -z "${PYRO_CONFIG_FILE}" ] ; then
	  export PYRO_CONFIG_FILE='/etc/Pyro.conf'
	fi
EOF
# (Do Not DETAB! See man bash re 'here' documents and dash before EOF)

  cat <<-EOF  >$RPM_BUILD_ROOT/etc/profile.d/pyro.csh
	test -z `printenv PYRO_CONFIG_FILE`
	if (\$status == 0) then
	  setenv PYRO_CONFIG_FILE '/etc/Pyro.conf'
	endif
EOF
# (Do Not DETAB! See man bash re 'here' documents and dash before EOF)

  cp Pyro.conf $RPM_BUILD_ROOT/etc/

  cat <<-EOF  >$RPM_BUILD_ROOT/var/pyro/namesvc
	#!/bin/sh
	cd /var/pyro
	export PYRO_CONFIG_FILE=/etc/Pyro.conf

	su pyro -c "ns -d /var/pyro" >> /var/log/pyro_namesvc 2>&1  &

	# Record PID of Last Process Spawned
	echo \$! >/var/run/pyro_namesvc.pid
EOF
# (Do Not DETAB! See man bash re 'here' documents and dash before EOF)

  cat <<-EOF  >$RPM_BUILD_ROOT/var/pyro/eventsvc
	#!/bin/sh
	cd /var/pyro
	export PYRO_CONFIG_FILE=/etc/Pyro.conf

	su pyro -c es >> /var/log/pyro_eventsvc 2>&1 &

	# Record PID of Last Process Spawned
	echo \$! >/var/run/pyro_eventsvc.pid
EOF
# (Do Not DETAB! See man bash re 'here' documents and dash before EOF)

#  # Create Safe Preowned Logfiles
#  # (Otherwise a symlink-redirect attack may be possible!)
  touch $RPM_BUILD_ROOT/var/log/pyro_namesvc
  touch $RPM_BUILD_ROOT/var/log/pyro_eventsvc

  install -m 0755 %{SOURCE1} $RPM_BUILD_ROOT/etc/rc.d/init.d/pyro_namesvc
  install -m 0755 %{SOURCE2} $RPM_BUILD_ROOT/etc/rc.d/init.d/pyro_eventsvc

####
# Section: Delivery Install/Uninstall Scripts (Pre/Post Install/Erase Scripts)
####

%pre
  /usr/sbin/useradd -o -r -M -s /bin/bash -d /var/pyro -c "Pyro Objects Server" pyro >/dev/null 2>&1

%post
  /sbin/chkconfig --add pyro_namesvc
  /sbin/chkconfig --add pyro_eventsvc

%preun
  if [ "$1" = 0 ] ; then
    /etc/rc.d/init.d/pyro_namesvc stop > /dev/null 2>&1
    /sbin/chkconfig --del pyro_namesvc

    /etc/rc.d/init.d/pyro_eventsvc stop > /dev/null 2>&1
    /sbin/chkconfig --del pyro_eventsvc
  fi

%postun
  if [ $1 = 0 ] ; then
	userdel pyro >/dev/null 2>&1 || :
  fi
  if [ "$1" -ge "1" ]; then
	/etc/rc.d/init.d/lpd condrestart > /dev/null 2>&1
  fi

####
# Section: Verify Script (Check for Proper Installation of Package)
####

####
# Section: Clean Script (Tidy Up Build Area After a Build Completes)
####
%clean
  rm -rf $RPM_BUILD_ROOT

####
# Section: Files (List of Files w/Attributes Making Up Package)
####

%files
  %defattr(-, root, root)

  %doc TODO LICENSE Readme.txt
  %doc docs/
  %doc examples/
  %doc Pyro.conf

  %attr(664, root, root) %config /etc/Pyro.conf

  /usr/lib/%{PYTHONDIR}/site-packages/*
  /usr/bin/*
  %attr(755, pyro, pyro) %dir /var/pyro/
  /etc/rc.d/init.d/*
  %attr(640, pyro, pyro) %config %verify(not size md5 mtime) /var/log/pyro_namesvc
  %attr(640, pyro, pyro) %config %verify(not size md5 mtime) /var/log/pyro_eventsvc

  %attr(755, root, root) %config(missingok) /etc/profile.d/pyro.csh
  %attr(755, root, root) %config(missingok) /etc/profile.d/pyro.sh

  %attr(755, root, root) %config /var/pyro/namesvc
  %attr(755, root, root) %config /var/pyro/eventsvc

%changelog
* Tue Oct 16 2001 Jeff Rush <jrush@taupro.com>
  Packaged Pyro 2.1.

